Stopper
=======

.. currentmodule:: pykeen.stoppers

.. autoclass:: Stopper
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Stopper.get_summary_dict
      ~Stopper.load_summary_dict_from_training_loop_checkpoint
      ~Stopper.should_evaluate
      ~Stopper.should_stop

   .. rubric:: Methods Documentation

   .. automethod:: get_summary_dict
   .. automethod:: load_summary_dict_from_training_loop_checkpoint
   .. automethod:: should_evaluate
   .. automethod:: should_stop
